@@ -2,7 +2,7 @@
  *   SPDX-FileCopyrightText: 2021 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
  *   SPDX-FileCopyrightText: 2018 Drew DeVault <sir@cmpwn.com>
  *
- *   SPDX-License-Identifier: LGPL-3.0-or-later
+ *   SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #ifndef _LAYERSHELLINTEGRATION_P_H
@@ -18,14 +18,19 @@ class QWaylandXdgActivationV1;
 namespace LayerShellQt
 {
 
-class LAYERSHELLQT_EXPORT QWaylandLayerShellIntegration : public QtWaylandClient::QWaylandShellIntegrationTemplate<QWaylandLayerShellIntegration>, public QtWayland::zwlr_layer_shell_v1
+class LAYERSHELLQT_EXPORT QWaylandLayerShellIntegration : public QtWaylandClient::QWaylandShellIntegrationTemplate<QWaylandLayerShellIntegration>,
+                                                          public QtWayland::zwlr_layer_shell_v1
 {
 public:
     QWaylandLayerShellIntegration();
     ~QWaylandLayerShellIntegration() override;
 
-    QWaylandXdgActivationV1 *activation() const { return m_xdgActivation.data(); }
+    QWaylandXdgActivationV1 *activation() const
+    {
+        return m_xdgActivation.data();
+    }
     QtWaylandClient::QWaylandShellSurface *createShellSurface(QtWaylandClient::QWaylandWindow *window) override;
+
 private:
     QScopedPointer<QWaylandXdgActivationV1> m_xdgActivation;
 };
